Version 5.0～6.0
=================

Version5.0～6.0までのリリースノートです。

## :package: 5.0.5

:fontawesome-solid-calendar: `2024-09-04`

!!! note "セキュリティアップデート"

## :package: 5.0.4

:fontawesome-solid-calendar: `2024-07-13`

!!! note "セキュリティアップデート"

## :package: 5.0.3

:fontawesome-solid-calendar: `2024-06-20`

!!! note "セキュリティアップデート"

## :package: 5.0.2

:fontawesome-solid-calendar: `2024-05-26`

!!! note "セキュリティアップデート"

!!! bug "Dockerfileの不備を修正"

## :package: 5.0.1

:fontawesome-solid-calendar: `2024-05-04`

!!! note "セキュリティアップデート"

## :package: 5.0.0

:fontawesome-solid-calendar: `2024-04-28`

!!! danger "Python3.7のサポートを終了しました"

!!! note "Blackの代わりにRuffを使用するようにしました"

